import React, { Fragment, useState } from 'react';
import type { Ingredients, IngredientNames } from '@/interfaces/Ingredients'; 
import Burger from '@/components/Burger/Burger';
import BuildControls from '@/components/BuildControls/BuildControls';
import { IngredientPrices } from '@/helpers/IngPrice';

const BurgerBuilder = () => {
    const [totalPrice, setTotalPrice] = useState<number>(IngredientPrices.bread);
    const [ingredients, setIngredients] = useState<Ingredients>({
        salad: 0,
        meat: 0,
        bacon: 0,
        cheese: 0
    });

    const onLessClick = (ingType: IngredientNames) => {
        const ingredientsCopy = {...ingredients};
        if(ingredientsCopy[ingType] > 0) {
            ingredientsCopy[ingType] -= 1;
            setIngredients(ingredientsCopy);
            setTotalPrice(prevState => prevState - IngredientPrices[ingType]);
        };
    };

    const onMoreClick = (ingType: IngredientNames) => {
        const ingredientsCopy = {...ingredients};
        ingredientsCopy[ingType] += 1;
        setTotalPrice(prevState => prevState + IngredientPrices[ingType]);
        setIngredients(ingredientsCopy);
    };

    return (
        <>
            <Burger ingredients={ingredients}/>
            <BuildControls 
                price={totalPrice}
                onLessClick={onLessClick} 
                onMoreClick={onMoreClick}
                ingredients={ingredients}
            />
        </>
    )
}

export default BurgerBuilder;
